Using Rally for OpenStack deployment
====================================

This directory contains various input files for **rally deployment create**
command. This command will deploy OpenStack and register it to Rally DB.


devstack-in-existing-servers.json
---------------------------------

Deploy with DevStack OpenStack cloud on specified servers.


devstack-in-lxc.json
--------------------

Deploy DevStack cluster in LXC containers


devstack-in-openstack.json
--------------------------

Create require VM in specified OpenStack cloud and deploy using DevStack
OpenStack on them.


devstack-lxc-engine-in-existing-servers.json
--------------------------------------------

See *devstack-lxc-engine-in-existing-servers.rst* for details

fuel-ha.json
------------

Deploy High Availability FUEL cluster.

fuel-multinode.json
-------------------

Deploy Multinode FUEL cluster.
